@@ -13,10 +13,11 @@
 
 #include <cstddef>
 #include <string>
-#if MPPP_CPLUSPLUS >= 201703L
+#include <type_traits>
+
+#if defined(MPPP_HAVE_STRING_VIEW)
 #include <string_view>
 #endif
-#include <type_traits>
 
 #include <mp++/detail/type_traits.hpp>
 
@@ -34,7 +35,7 @@ using is_cpp_integral_interoperable
 
 template <typename T>
 #if defined(MPPP_HAVE_CONCEPTS)
-concept bool CppIntegralInteroperable = is_cpp_integral_interoperable<T>::value;
+MPPP_CONCEPT_DECL CppIntegralInteroperable = is_cpp_integral_interoperable<T>::value;
 #else
 using cpp_integral_interoperable_enabler = detail::enable_if_t<is_cpp_integral_interoperable<T>::value, int>;
 #endif
@@ -46,7 +47,7 @@ using is_cpp_unsigned_integral_interoperable
 
 template <typename T>
 #if defined(MPPP_HAVE_CONCEPTS)
-concept bool CppUnsignedIntegralInteroperable = is_cpp_unsigned_integral_interoperable<T>::value;
+MPPP_CONCEPT_DECL CppUnsignedIntegralInteroperable = is_cpp_unsigned_integral_interoperable<T>::value;
 #else
 using cpp_unsigned_integral_interoperable_enabler
     = detail::enable_if_t<is_cpp_unsigned_integral_interoperable<T>::value, int>;
@@ -59,7 +60,7 @@ using is_cpp_signed_integral_interoperable
 
 template <typename T>
 #if defined(MPPP_HAVE_CONCEPTS)
-concept bool CppSignedIntegralInteroperable = is_cpp_signed_integral_interoperable<T>::value;
+MPPP_CONCEPT_DECL CppSignedIntegralInteroperable = is_cpp_signed_integral_interoperable<T>::value;
 #else
 using cpp_signed_integral_interoperable_enabler
     = detail::enable_if_t<is_cpp_signed_integral_interoperable<T>::value, int>;
@@ -77,7 +78,7 @@ using is_cpp_floating_point_interoperable
 
 template <typename T>
 #if defined(MPPP_HAVE_CONCEPTS)
-concept bool CppFloatingPointInteroperable = is_cpp_floating_point_interoperable<T>::value;
+MPPP_CONCEPT_DECL CppFloatingPointInteroperable = is_cpp_floating_point_interoperable<T>::value;
 #else
 using cpp_floating_point_interoperable_enabler
     = detail::enable_if_t<is_cpp_floating_point_interoperable<T>::value, int>;
@@ -89,7 +90,7 @@ using is_cpp_interoperable
 
 template <typename T>
 #if defined(MPPP_HAVE_CONCEPTS)
-concept bool CppInteroperable = is_cpp_interoperable<T>::value;
+MPPP_CONCEPT_DECL CppInteroperable = is_cpp_interoperable<T>::value;
 #else
 using cpp_interoperable_enabler = detail::enable_if_t<is_cpp_interoperable<T>::value, int>;
 #endif
@@ -112,7 +113,7 @@ using is_string_type
                           // NOTE: detail::remove_cv_t does remove cv qualifiers from arrays.
                           detail::conjunction<std::is_array<detail::remove_cv_t<T>>,
                                               std::is_same<detail::remove_extent_t<detail::remove_cv_t<T>>, char>>
-#if MPPP_CPLUSPLUS >= 201703L
+#if defined(MPPP_HAVE_STRING_VIEW)
                           ,
                           std::is_same<detail::remove_cv_t<T>, std::string_view>
 #endif
@@ -120,7 +121,7 @@ using is_string_type
 
 template <typename T>
 #if defined(MPPP_HAVE_CONCEPTS)
-concept bool StringType = is_string_type<T>::value;
+MPPP_CONCEPT_DECL StringType = is_string_type<T>::value;
 #else
 using string_type_enabler = detail::enable_if_t<is_string_type<T>::value, int>;
 #endif
